@@ -82,11 +82,15 @@ FBReader &FBReader::Instance() {
 FBReader::FBReader(const std::string &bookToOpen) :
 	ZLApplication("FBReader"),
 	QuitOnCancelOption(ZLCategoryKey::CONFIG, OPTIONS, "QuitOnCancel", false),
+	AlwaysStartInLibraryOption(ZLCategoryKey::CONFIG, OPTIONS, "AlwaysStartInLibrary", false),
 	KeyScrollingDelayOption(ZLCategoryKey::CONFIG, "Scrollings", "Delay", 0, 2000, 100),
 	LinesToScrollOption(ZLCategoryKey::CONFIG, "SmallScrolling", "LinesToScroll", 1, 20, 1),
 	LinesToKeepOption(ZLCategoryKey::CONFIG, "LargeScrolling", "LinesToKeepOption", 0, 20, 0),
 	EnableTapScrollingOption(ZLCategoryKey::CONFIG, "TapScrolling", "Enabled", true),
 	TapScrollingOnFingerOnlyOption(ZLCategoryKey::CONFIG, "TapScrolling", "FingerOnly", true),
+	TapScrollingOnDragOnlyOption(ZLCategoryKey::CONFIG, "TapScrolling", "DragOnly", true),
+	VariableDragOption(ZLCategoryKey::CONFIG, "TapScrolling", "VariableDrag", false),
+	VariableDragLengthOption(ZLCategoryKey::CONFIG, "TapScrolling", "VariableDragLength", 0, 800, 100),
 	UseSeparateBindingsOption(ZLCategoryKey::CONFIG, "KeysOptions", "UseSeparateBindings", false),
 	EnableSingleClickDictionaryOption(ZLCategoryKey::CONFIG, "Dictionary", "SingleClick", false),
 	myBindings0(new ZLKeyBindings("Keys")),
@@ -181,6 +185,9 @@ void FBReader::initWindow() {
 		if (!myBookToOpen.empty()) {
 			createBook(myBookToOpen, book);
 		}
+		if ((book.isNull()) && AlwaysStartInLibraryOption.value()) {
+			book = BooksDBUtil::getBook(helpFileName("en"));
+		}
 		if (book.isNull()) {
 			const BookList &books = Library::Instance().recentBooks();
 			if (!books.empty()) {
@@ -197,7 +204,16 @@ void FBReader::initWindow() {
 	}
 	refreshWindow();
 
+#ifdef MAEMO_VERSION
+    // Update clock once a minute on Maemo, to save battery power
+	ZLTimeManager::Instance().addTask(new TimeUpdater(), 60000);
+#else
 	ZLTimeManager::Instance().addTask(new TimeUpdater(), 1000);
+#endif
+
+	if (AlwaysStartInLibraryOption.value()) {
+		setMode(LIBRARY_MODE);
+	}
 }
 
 void FBReader::refreshWindow() {
