@@ -63,12 +63,16 @@ public:
 
 public:
 	ZLBooleanOption QuitOnCancelOption;
+	ZLBooleanOption AlwaysStartInLibraryOption;
 
 	ZLIntegerRangeOption KeyScrollingDelayOption;
 	ZLIntegerRangeOption LinesToScrollOption;
 	ZLIntegerRangeOption LinesToKeepOption;
 	ZLBooleanOption EnableTapScrollingOption;
 	ZLBooleanOption TapScrollingOnFingerOnlyOption;
+	ZLBooleanOption TapScrollingOnDragOnlyOption;
+	ZLBooleanOption VariableDragOption;
+	ZLIntegerRangeOption VariableDragLengthOption;
 
 	ZLBooleanOption UseSeparateBindingsOption;
 
